Command samples

Equalizer v0.0.3
Play examples
/text/searchandplay/mymusic/albums/the
search any album that contains 'the'
/text/play/station/1
play second station button (mapping to real station button is unknown )
/text/play/radio/1
play second local radio station
Info examples
/text/info/room
get current room
/text/info/title
get current title
/text/info/remaining
get remaining time of track
/text/status
status information of your raumfeld system
/text/room/kitchen
set room kitchen as current room
/text/volume/30
set volume to 30 (of last room selected)
/text/volume/tv/40
set volume to 40 (of room tv)
/text/volume/increase
increase volume by 5
/text/volume/louder
increase volume by 5
/text/silence
mute
Transport action examples
/text/action/continue
unmute
/text/action/stop
stop
/text/action/lower
lower volume
/text/action/higher
higher volume
/text/volume/high
set a high volume